You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by cm...@apache.org on 2013/03/29 19:31:26 UTC

svn commit: r1462581 - /subversion/trunk/subversion/include/svn_fs.h

Author: cmpilato
Date: Fri Mar 29 18:31:26 2013
New Revision: 1462581

URL: http://svn.apache.org/r1462581
Log:
* subversion/include/svn_fs.h
  (svn_fs_process_contents_func_t): Rename 'pool' to 'scratch_pool',
    and update docstring for clarity.

Modified:
    subversion/trunk/subversion/include/svn_fs.h

Modified: subversion/trunk/subversion/include/svn_fs.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_fs.h?rev=1462581&r1=1462580&r2=1462581&view=diff
==============================================================================
--- subversion/trunk/subversion/include/svn_fs.h (original)
+++ subversion/trunk/subversion/include/svn_fs.h Fri Mar 29 18:31:26 2013
@@ -1882,11 +1882,11 @@ svn_fs_file_contents(svn_stream_t **cont
                      apr_pool_t *pool);
 
 /**
- * Callback function type that gets presented with a immutable non-NULL
- * @a contents of @a len bytes.  Further parameters may be passed through
- * in @a baton.
+ * Callback function type used with svn_fs_try_process_file_contents()
+ * that delivers the immutable, non-NULL @a contents of @a len bytes.
+ * @a baton is an implementation-specific closure.
  *
  * Allocations must be made in @a pool.
  *
  * @since New in 1.8.
  */
@@ -1894,7 +1894,7 @@ typedef svn_error_t *
 (*svn_fs_process_contents_func_t)(const unsigned char *contents,
                                   apr_size_t len,
                                   void *baton,
-                                  apr_pool_t *pool);
+                                  apr_pool_t *scratch_pool);
 
 /** Efficiently deliver the contents of the file @a path in @a root
  * via @a processor (with @a baton), setting @a *success to @c TRUE
@@ -1882,11 +1882,11 @@ svn_fs_file_contents(svn_stream_t **cont
  *
- * Allocations must be made in @a pool.
+ * Use @a scratch_pool for allocations.
  *
  * @since New in 1.8.